# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script.provider
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XScript(XInterface_8f010a43):
    """
    This interface represents an invocable script or UNO function.

    See Also:
        `API XScript <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1provider_1_1XScript.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script.provider'
    __ooo_full_ns__: str = 'com.sun.star.script.provider.XScript'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.provider.XScript'

    @abstractmethod
    def invoke(self, aParams: typing.Tuple[object, ...], aOutParamIndex: uno.ByteSequence, aOutParam: typing.Tuple[object, ...]) -> object:
        """
        invoke the script or function represented by the implementing object
        
        For example, if the script had the signaturelong foo( [inout] string a, [in] string b, [out] string c ) the call would look likebar.invoke( {\"foo\", \"foo2\", \"this-is-ignored\" }, aOutParamIndex, aOutParam); and after the call the out sequences would contain

        * ``aOutParamIndex`` is an out direction argument.
        * ``aOutParam`` is an out direction argument.

        Raises:
            : ````
            com.sun.star.reflection.InvocationTargetException: ``InvocationTargetException``
        """
        ...

__all__ = ['XScript']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class AliasProgrammaticPair(object):
    """
    Struct Class

    represents an entry from a component which implements the XLocalizedAliases.

    See Also:
        `API AliasProgrammaticPair <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1AliasProgrammaticPair.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.AliasProgrammaticPair'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.util.AliasProgrammaticPair'
    """Literal Constant ``com.sun.star.util.AliasProgrammaticPair``"""

    def __init__(self, Alias: typing.Optional[str] = '', ProgrammaticName: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Alias (str, optional): Alias value.
            ProgrammaticName (str, optional): ProgrammaticName value.
        """
        super().__init__()

        if isinstance(Alias, AliasProgrammaticPair):
            oth: AliasProgrammaticPair = Alias
            self.Alias = oth.Alias
            self.ProgrammaticName = oth.ProgrammaticName
            return

        kargs = {
            "Alias": Alias,
            "ProgrammaticName": ProgrammaticName,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._alias = kwargs["Alias"]
        self._programmatic_name = kwargs["ProgrammaticName"]


    @property
    def Alias(self) -> str:
        """
        determines the name which is registered as an alias for a programmatic name.
        """
        return self._alias

    @Alias.setter
    def Alias(self, value: str) -> None:
        self._alias = value

    @property
    def ProgrammaticName(self) -> str:
        """
        determines which programmatic name belongs to the alias.
        """
        return self._programmatic_name

    @ProgrammaticName.setter
    def ProgrammaticName(self, value: str) -> None:
        self._programmatic_name = value


__all__ = ['AliasProgrammaticPair']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.key_event import KeyEvent as KeyEvent_7a78097f
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9

class XInplaceObject(XInterface_8f010a43):
    """
    represents common functionality for inplace embedded objects.

    See Also:
        `API XInplaceObject <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XInplaceObject.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XInplaceObject'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XInplaceObject'

    @abstractmethod
    def enableModeless(self, bEnable: bool) -> None:
        """
        enables or disables modeless dialogs of the object.
        
        In case container wants to show a modal dialog it should disable modeless of embedded object dialogs with this call. Later the same call can be used to enable it.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def setObjectRectangles(self, aPosRect: Rectangle_84b109e9, aClipRect: Rectangle_84b109e9) -> None:
        """
        sets the visible part of the inplace object.
        
        Both rectangles are provided in object's parent window coordinates in pixels. The intersection of rectangles specifies the visible part of the object. In case the position window has a size that is different from object's visual area size, the object should either scale or deactivate.
        
        The method must activate object repainting.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def translateAccelerators(self, aKeys: typing.Tuple[KeyEvent_7a78097f, ...]) -> None:
        """
        provides accelerator table the container wants to use during inplace editing.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
        ...

__all__ = ['XInplaceObject']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.inspection
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.inspection.InteractiveSelectionResult import InteractiveSelectionResultProto

class InteractiveSelectionResult(Enum):
    """
    Enum Class


    See Also:
        `API InteractiveSelectionResult <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1inspection.html#a2c7cbb6dbe76b989188c75ba8e400876>`_
    """
    __ooo_ns__: str = 'com.sun.star.inspection'
    __ooo_full_ns__: str = 'com.sun.star.inspection.InteractiveSelectionResult'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.inspection.InteractiveSelectionResult'

    Cancelled = cast("InteractiveSelectionResultProto", 'Cancelled')
    """
    The interactive selection of a property value was canceled.
    """
    ObtainedValue = cast("InteractiveSelectionResultProto", 'ObtainedValue')
    """
    The interactive selection of a property value succeeded, a new property value has been obtained, but not yet set at the inspected component.
    
    In this case, the obtained value is passed to the caller of XPropertyHandler.onInteractivePropertySelection(), which is responsible for forwarding this value to the inspected component.
    """
    Pending = cast("InteractiveSelectionResultProto", 'Pending')
    """
    The interactive selection of a property value is still pending.
    """
    Success = cast("InteractiveSelectionResultProto", 'Success')
    """
    The interactive selection of a property value succeeded, and the new property value chosen by the user has already been set at the inspected component.
    """

__all__ = ['InteractiveSelectionResult']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from ..table.shadow_format import ShadowFormat as ShadowFormat_bb840bdf
    from ..table.table_border import TableBorder as TableBorder_aedf0b56
    from ..table.table_border2 import TableBorder2 as TableBorder2_ba670b88
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.awt.FontSlant import FontSlantProto
    from com.sun.star.table.CellHoriJustify import CellHoriJustifyProto
    from com.sun.star.table.CellOrientation import CellOrientationProto

class TableAutoFormatField(XPropertySet_bc180bfa):
    """
    Service Class

    represents a field in an AutoFormat.
    
    A field contains all cell properties for a specific position in an AutoFormat.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API TableAutoFormatField <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.TableAutoFormatField'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CellBackColor(self) -> Color_68e908c5:
        """
        contains the cell background color.
        """
        ...

    @abstractproperty
    def CharColor(self) -> Color_68e908c5:
        """
        contains the value of the text color.
        """
        ...

    @abstractproperty
    def CharContoured(self) -> bool:
        """
        is TRUE if the characters are contoured.
        """
        ...

    @abstractproperty
    def CharCrossedOut(self) -> bool:
        """
        is TRUE if the characters are crossed out.
        """
        ...

    @abstractproperty
    def CharFontCharSet(self) -> str:
        """
        contains the value of the character set of the western font.
        """
        ...

    @abstractproperty
    def CharFontCharSetAsian(self) -> str:
        """
        contains the value of the character set of the Asian font.
        """
        ...

    @abstractproperty
    def CharFontCharSetComplex(self) -> str:
        """
        contains the value of the character set of the complex font.
        """
        ...

    @abstractproperty
    def CharFontFamily(self) -> str:
        """
        contains the value of the western font family.
        """
        ...

    @abstractproperty
    def CharFontFamilyAsian(self) -> str:
        """
        contains the value of the Asian font family.
        """
        ...

    @abstractproperty
    def CharFontFamilyComplex(self) -> str:
        """
        contains the value of the complex font family.
        """
        ...

    @abstractproperty
    def CharFontName(self) -> str:
        """
        specifies the name of the western font.
        """
        ...

    @abstractproperty
    def CharFontNameAsian(self) -> str:
        """
        specifies the name of the Asian font.
        """
        ...

    @abstractproperty
    def CharFontNameComplex(self) -> str:
        """
        specifies the name of the complex font.
        """
        ...

    @abstractproperty
    def CharFontPitch(self) -> str:
        """
        contains the value of the pitch of the western font.
        """
        ...

    @abstractproperty
    def CharFontPitchAsian(self) -> str:
        """
        contains the value of the pitch of the Asian font.
        """
        ...

    @abstractproperty
    def CharFontPitchComplex(self) -> str:
        """
        contains the value of the pitch of the complex font.
        """
        ...

    @abstractproperty
    def CharFontStyleName(self) -> str:
        """
        specifies the name of the western font style.
        """
        ...

    @abstractproperty
    def CharFontStyleNameAsian(self) -> str:
        """
        specifies the name of the Asian font style.
        """
        ...

    @abstractproperty
    def CharFontStyleNameComplex(self) -> str:
        """
        specifies the name of the complex font style.
        """
        ...

    @abstractproperty
    def CharHeight(self) -> float:
        """
        contains the height of characters of the western font in point.
        """
        ...

    @abstractproperty
    def CharHeightAsian(self) -> float:
        """
        contains the height of characters of the Asian font in point.
        """
        ...

    @abstractproperty
    def CharHeightComplex(self) -> float:
        """
        contains the height of characters of the complex font in point.
        """
        ...

    @abstractproperty
    def CharPosture(self) -> FontSlantProto:
        """
        contains the value of the posture of characters of the western font.
        """
        ...

    @abstractproperty
    def CharPostureAsian(self) -> FontSlantProto:
        """
        contains the value of the posture of characters of the Asian font.
        """
        ...

    @abstractproperty
    def CharPostureComplex(self) -> FontSlantProto:
        """
        contains the value of the posture of characters of the complex font.
        """
        ...

    @abstractproperty
    def CharShadowed(self) -> bool:
        """
        is TRUE if the characters are shadowed.
        """
        ...

    @abstractproperty
    def CharUnderline(self) -> int:
        """
        contains the value for the character underline.
        """
        ...

    @abstractproperty
    def CharWeight(self) -> float:
        """
        contains the value for the weight of characters of the western font.
        """
        ...

    @abstractproperty
    def CharWeightAsian(self) -> float:
        """
        contains the value for the weight of characters of the Asian font.
        """
        ...

    @abstractproperty
    def CharWeightComplex(self) -> float:
        """
        contains the value for the weight of characters of the complex font.
        """
        ...

    @abstractproperty
    def HoriJustify(self) -> CellHoriJustifyProto:
        """
        specifies the horizontal alignment of the cell contents.
        """
        ...

    @abstractproperty
    def IsCellBackgroundTransparent(self) -> bool:
        """
        is TRUE if the cell background is transparent.
        
        In this case the TableAutoFormatField.CellBackColor value is not used.
        """
        ...

    @abstractproperty
    def IsTextWrapped(self) -> bool:
        """
        is TRUE if text breaks automatically at cell borders.
        """
        ...

    @abstractproperty
    def Orientation(self) -> CellOrientationProto:
        """
        contains the orientation of the cell contents (i.e.
        
        top-to-bottom or stacked).
        """
        ...

    @abstractproperty
    def ParaBottomMargin(self) -> int:
        """
        contains the margin between cell contents and bottom border (in 1/100 mm).
        """
        ...

    @abstractproperty
    def ParaLeftMargin(self) -> int:
        """
        contains the margin between cell contents and left border (in 1/100 mm).
        """
        ...

    @abstractproperty
    def ParaRightMargin(self) -> int:
        """
        contains the margin between cell contents and right border (in 1/100 mm).
        """
        ...

    @abstractproperty
    def ParaTopMargin(self) -> int:
        """
        contains the margin between cell contents and top border (in 1/100 mm).
        """
        ...

    @abstractproperty
    def RotateAngle(self) -> int:
        """
        contains the rotation angle of the cell contents.
        """
        ...

    @abstractproperty
    def RotateReference(self) -> int:
        """
        contains the reference edge of the cell rotation.
        
        changed from com.sun.star.table.CellVertJustify to long in LibO 3.5
        """
        ...

    @abstractproperty
    def ShadowFormat(self) -> ShadowFormat_bb840bdf:
        """
        contains a description of the shadow.
        """
        ...

    @abstractproperty
    def TableBorder(self) -> TableBorder_aedf0b56:
        """
        property containing a description of the cell border.
        
        **since**
        
            OOo 1.1.2
        """
        ...

    @abstractproperty
    def TableBorder2(self) -> TableBorder2_ba670b88:
        """
        property containing a description of the cell border.
        
        Preferred over com.sun.star.table.TableBorder TableBorder.
        
        **since**
        
            LibreOffice 3.6
        """
        ...

    @abstractproperty
    def VertJustify(self) -> int:
        """
        specifies the vertical alignment of the cell contents.
        
        changed from com.sun.star.table.CellVertJustify to long in LibO 3.5
        """
        ...


__all__ = ['TableAutoFormatField']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ItemStyle(metaclass=UnoConstMeta, type_name="com.sun.star.ui.ItemStyle", name_space="com.sun.star.ui"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.ui.ItemStyle``"""
        pass

    class ItemStyleEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.ui.ItemStyle", name_space="com.sun.star.ui"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.ui.ItemStyle`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.ui import ItemStyle as ItemStyle
    else:
        # keep document generators happy
        from ...lo.ui.item_style import ItemStyle as ItemStyle

    class ItemStyleEnum(IntEnum):
        """
        Enum of Const Class ItemStyle

        specifies styles which influence the appearance and the behavior of an user interface item.
        
        These styles are only valid if the item describes a toolbar or statusbar item. The style values can be combined with the OR operator. Styles which are not valid for an item will be ignored by the implementation.There are two styles where only one value is valid: Alignment:
        
        Drawing:
        
        **since**
        
            OOo 2.0
        """
        ALIGN_LEFT = ItemStyle.ALIGN_LEFT
        """
        specifies how the output of the item is aligned in the bounding box of the user interface element.
        
        This style is only valid for an item which describes a statusbar item. Draw item with a left aligned output.
        """
        ALIGN_CENTER = ItemStyle.ALIGN_CENTER
        """
        specifies how the output of the item is aligned in the bounding box of the user interface element.
        
        This style is only valid for an item which describes a statusbar item. Draw item with a centered aligned output.
        """
        ALIGN_RIGHT = ItemStyle.ALIGN_RIGHT
        """
        specifies how the output of the item is aligned in the bounding box of the user interface element.
        
        This style is only valid for an item which describes a statusbar item. Draw item with a right aligned output.
        """
        DRAW_OUT3D = ItemStyle.DRAW_OUT3D
        """
        specifies how the implementation should draw the item.
        
        This style is only valid for an item which describes a statusbar item. Draw item with an embossed 3D effect.
        """
        DRAW_IN3D = ItemStyle.DRAW_IN3D
        """
        specifies how the implementation should draw the item.
        
        This style is only valid for an item which describes a statusbar item. Draw item with an impressed 3D effect.
        """
        DRAW_FLAT = ItemStyle.DRAW_FLAT
        """
        specifies how the implementation should draw the item.
        
        This style is only valid for an item which describes a statusbar item. Draw item without an 3D effect.
        """
        OWNER_DRAW = ItemStyle.OWNER_DRAW
        """
        specifies whether or not an item is displayed using an external function.
        
        This style is only valid if the item describes a statusbar item.
        """
        AUTO_SIZE = ItemStyle.AUTO_SIZE
        """
        specifies whether or not the size of the item is set automatically by the parent user interface element.
        
        This style is only valid if the item describes a toolbar or statusbar item.
        """
        RADIO_CHECK = ItemStyle.RADIO_CHECK
        """
        determines whether the item unchecks neighbor entries which have also this style set.
        
        This style is only valid if the item describes a toolbar item.
        """
        ICON = ItemStyle.ICON
        """
        specifies if an icon is placed on left side of the text, like an entry in a taskbar.
        
        This style is only valid if the item describes a toolbar item and visible if style of the toolbar is set to symboltext.
        
        This style can also be used for custom toolbars and menus, in a custom toolbar an item's Style setting can used to override the toolbar container setting, the style can be bitwise OR-ed with com.sun.star.ui.ItemStyle.TEXT to define text, text+icon or icon only is to be displayed. Similarly for menu items, an items Style can override the application setting to display either text or icon (note: for menu an icon only setting interpreted as icon+text)
        """
        DROP_DOWN = ItemStyle.DROP_DOWN
        """
        specifies that the item supports a dropdown menu or toolbar for additional functions.
        
        This style is only valid if the item describes a toolbar item.
        """
        REPEAT = ItemStyle.REPEAT
        """
        indicates that the item continues to execute the command while you click and hold the mouse button.
        
        This style is only valid if the item describes a toolbar item.
        """
        DROPDOWN_ONLY = ItemStyle.DROPDOWN_ONLY
        """
        indicates that the item only supports a dropdown menu or toolbar for additional functions.
        
        There is no function on the button itself.
        
        This style is only valid if the item describes a toolbar item.
        """
        TEXT = ItemStyle.TEXT
        """
        indicates if icon, text or text+icon is displayed for the item.
        
        This style can be used for custom toolbars and menus, in a custom toolbar an item's Style setting can used to override the toolbar container setting, the style can be bitwise OR-ed with com.sun.star.ui.ItemStyle.ICON to define text, text+icon or icon only is to be displayed. Similarly for menu items, an items Style can override the application setting to display either text or icon (note: for menu an icon only setting interpreted as icon+text)
        """
        MANDATORY = ItemStyle.MANDATORY
        """
        marks always visible element which can not be removed when statusbar width is not sufficient.
        
        **since**
        
            LibreOffice 6.1
        """

__all__ = ['ItemStyle', 'ItemStyleEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XBroadcaster(XInterface_8f010a43):
    """
    allows to control notification behavior of a broadcaster.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XBroadcaster <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XBroadcaster.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XBroadcaster'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XBroadcaster'

    @abstractmethod
    def lockBroadcasts(self) -> None:
        """
        suspends broadcasts to the registered listeners.
        
        The calls to XBroadcaster.lockBroadcasts() and XBroadcaster.unlockBroadcasts() may be nested and even overlapping, but they must be in pairs. While there is at least one lock remaining, no broadcasts are sent to registered listeners.
        """
        ...
    @abstractmethod
    def unlockBroadcasts(self) -> None:
        """
        resumes the broadcasts which were suspended by XBroadcaster.lockBroadcasts().
        
        The calls to XBroadcaster.lockBroadcasts() and XBroadcaster.unlockBroadcasts() may be nested and even overlapping, but they must be in pairs. While there is at least one lock remaining, no broadcasts are sent to registered listeners.
        
        Pending broadcasts will be sent immediately after the last call to XBroadcaster.lockBroadcasts() is matched by a call to XBroadcaster.unlockBroadcasts(). An implementation can decide to broadcast all pending notification in order or batch them in single broadcasts.
        """
        ...

__all__ = ['XBroadcaster']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
import typing
from abc import abstractmethod
from ..task.x_interaction_continuation import XInteractionContinuation as XInteractionContinuation_5af0108e
if typing.TYPE_CHECKING:
    from com.sun.star.ucb.RememberAuthentication import RememberAuthenticationProto

class XInteractionSupplyAuthentication(XInteractionContinuation_5af0108e):
    """
    An interaction continuation handing back some authentication data.
    
    This continuation is typically used in conjunction with AuthenticationRequest.

    See Also:
        `API XInteractionSupplyAuthentication <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XInteractionSupplyAuthentication.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.XInteractionSupplyAuthentication'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ucb.XInteractionSupplyAuthentication'

    @abstractmethod
    def canSetAccount(self) -> bool:
        """
        Specifies if an \"account\" value can be handed back.
        """
        ...
    @abstractmethod
    def canSetPassword(self) -> bool:
        """
        Specifies if a \"password\" value can be handed back.
        """
        ...
    @abstractmethod
    def canSetRealm(self) -> bool:
        """
        Specifies if a new \"realm\" value can be handed back.
        """
        ...
    @abstractmethod
    def canSetUserName(self) -> bool:
        """
        Specifies if a \"user name\" value can be handed back.
        """
        ...
    @abstractmethod
    def getRememberAccountModes(self, Default: RememberAuthenticationProto) -> typing.Tuple[RememberAuthentication_28a80f31, ...]:
        """
        Specifies the available modes of how long to remember the account.

        * ``Default`` is an out direction argument.
        """
        ...
    @abstractmethod
    def getRememberPasswordModes(self, Default: RememberAuthenticationProto) -> typing.Tuple[RememberAuthentication_28a80f31, ...]:
        """
        Specifies the available modes of how long to remember the password.

        * ``Default`` is an out direction argument.
        """
        ...
    @abstractmethod
    def setAccount(self, Account: str) -> None:
        """
        Set a new \"account\" value to hand back.
        
        This method should be called before com.sun.star.task.XInteractionContinuation.select(), and should only be called if XInteractionSupplyAuthentication.canSetAccount() returned TRUE.
        """
        ...
    @abstractmethod
    def setPassword(self, Password: str) -> None:
        """
        Set a new \"password\" value to hand back.
        
        This method should be called before com.sun.star.task.XInteractionContinuation.select(), and should only be called if XInteractionSupplyAuthentication.canSetPassword() returned TRUE.
        """
        ...
    @abstractmethod
    def setRealm(self, Realm: str) -> None:
        """
        Set a new \"realm\" value to hand back.
        
        This method should be called before com.sun.star.task.XInteractionContinuation.select(), and should only be called if XInteractionSupplyAuthentication.canSetRealm() returned TRUE.
        """
        ...
    @abstractmethod
    def setRememberAccount(self, Remember: RememberAuthenticationProto) -> None:
        """
        Set a new mode of how long to remember the account.
        
        This method should be called before com.sun.star.task.XInteractionContinuation.select(), and should only be called if XInteractionSupplyAuthentication.setAccount() is also called.
        """
        ...
    @abstractmethod
    def setRememberPassword(self, Remember: RememberAuthenticationProto) -> None:
        """
        Set a new mode of how long to remember the password.
        
        This method should be called before com.sun.star.task.XInteractionContinuation.select(), and should only be called if XInteractionSupplyAuthentication.setPassword() is also called.
        """
        ...
    @abstractmethod
    def setUserName(self, UserName: str) -> None:
        """
        Set a new \"user name\" value to hand back.
        
        This method should be called before com.sun.star.task.XInteractionContinuation.select(), and should only be called if XInteractionSupplyAuthentication.canSetUserName() returned TRUE.
        """
        ...

__all__ = ['XInteractionSupplyAuthentication']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame.status
import uno
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ItemState(metaclass=UnoConstMeta, type_name="com.sun.star.frame.status.ItemState", name_space="com.sun.star.frame.status"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.frame.status.ItemState``"""
        pass

    class ItemStateEnum(IntFlag, metaclass=ConstEnumMeta, type_name="com.sun.star.frame.status.ItemState", name_space="com.sun.star.frame.status"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.frame.status.ItemState`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.frame.status import ItemState as ItemState
    else:
        # keep document generators happy
        from ....lo.frame.status.item_state import ItemState as ItemState

    class ItemStateEnum(IntFlag):
        """
        Enum of Const Class ItemState

        these constants describe a state of an ItemStatus.
        
        **since**
        
            OOo 2.0
        """
        UNKNOWN = ItemState.UNKNOWN
        """
        specifies an unknown state.
        """
        DISABLED = ItemState.DISABLED
        """
        specifies that the property is currently disabled.
        """
        READ_ONLY = ItemState.READ_ONLY
        """
        specifies that the property is currently read-only.
        
        Deprecated: There is no equivalent in SfxItemState anymore due to not being used, so remove for simplification reasons and to prepare rework of Item/ItemSet/ItemPool stuff.
        
        There are only three usages of com.sun.star.frame.status.ItemState in the code which all set the internal SfxItem to SfxVoidItem when triggered, which is equivalent to state SfxItemState.DISABLED (see e.g. SfxItemSet.GetItemState), so READ_ONLY gets not used in internal handling, even when eventually existing UNO API usages hand it over the office.
        """
        DONT_CARE = ItemState.DONT_CARE
        """
        specifies that the property is currently in a don't care state.
        
        This is normally used if a selection provides more than one state for a property at the same time.
        """
        DEFAULT_VALUE = ItemState.DEFAULT_VALUE
        """
        specifies that the property is currently in a default state.
        """
        SET = ItemState.SET
        """
        specifies that the property is currently in a set state.
        """

__all__ = ['ItemState', 'ItemStateEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.xpath
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..dom.x_node import XNode as XNode_83fb09a5
    from ..dom.x_node_list import XNodeList as XNodeList_ae540b41
    from .xx_path_extension import XXPathExtension as XXPathExtension_194c0ea6
    from .xx_path_object import XXPathObject as XXPathObject_ee270d40

class XXPathAPI(XInterface_8f010a43):
    """

    See Also:
        `API XXPathAPI <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1xpath_1_1XXPathAPI.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.xpath'
    __ooo_full_ns__: str = 'com.sun.star.xml.xpath.XXPathAPI'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.xpath.XXPathAPI'

    @abstractmethod
    def eval(self, contextNode: XNode_83fb09a5, expr: str) -> XXPathObject_ee270d40:
        """
        Evaluate XPath Expression.

        Raises:
            com.sun.star.xml.xpath.XPathException: ``XPathException``
        """
        ...
    @abstractmethod
    def evalNS(self, contextNode: XNode_83fb09a5, expr: str, namespaceNode: XNode_83fb09a5) -> XXPathObject_ee270d40:
        """
        Evaluate XPath Expression.

        Raises:
            com.sun.star.xml.xpath.XPathException: ``XPathException``
        """
        ...
    @abstractmethod
    def registerExtension(self, serviceName: str) -> None:
        """
        """
        ...
    @abstractmethod
    def registerExtensionInstance(self, aExtension: XXPathExtension_194c0ea6) -> None:
        """
        """
        ...
    @abstractmethod
    def registerNS(self, prefix: str, url: str) -> None:
        """
        """
        ...
    @abstractmethod
    def selectNodeList(self, contextNode: XNode_83fb09a5, expr: str) -> XNodeList_ae540b41:
        """
        Evaluate an XPath expression to select a list of nodes.

        Raises:
            com.sun.star.xml.xpath.XPathException: ``XPathException``
        """
        ...
    @abstractmethod
    def selectNodeListNS(self, contextNode: XNode_83fb09a5, expr: str, namespaceNode: XNode_83fb09a5) -> XNodeList_ae540b41:
        """
        Evaluate an XPath expression to select a list of nodes.

        Raises:
            com.sun.star.xml.xpath.XPathException: ``XPathException``
        """
        ...
    @abstractmethod
    def selectSingleNode(self, contextNode: XNode_83fb09a5, expr: str) -> XNode_83fb09a5:
        """
        Evaluate an XPath expression to select a single node.

        Raises:
            com.sun.star.xml.xpath.XPathException: ``XPathException``
        """
        ...
    @abstractmethod
    def selectSingleNodeNS(self, contextNode: XNode_83fb09a5, expr: str, namespaceNode: XNode_83fb09a5) -> XNode_83fb09a5:
        """
        Evaluate an XPath expression to select a single node.

        Raises:
            com.sun.star.xml.xpath.XPathException: ``XPathException``
        """
        ...
    @abstractmethod
    def unregisterNS(self, prefix: str, url: str) -> None:
        """
        """
        ...

__all__ = ['XXPathAPI']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.security
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XAccessControlContext(XInterface_8f010a43):
    """
    An XAccessControlContext is used to make system resource access decisions based on the context it encapsulates.
    
    More specifically, it encapsulates a context and has methods to check permissions equivalent to XAccessController interface, with one difference: The XAccessControlContext makes access decisions based on the context it encapsulates, rather than that of the current execution thread.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessControlContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1security_1_1XAccessControlContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.security'
    __ooo_full_ns__: str = 'com.sun.star.security.XAccessControlContext'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.security.XAccessControlContext'

    @abstractmethod
    def checkPermission(self, perm: object) -> None:
        """
        Determines whether the access request indicated by the specified permission should be allowed or denied, based on this context.
        
        The semantics are equivalent to the security permission classes of the Java platform.
        
        You can also pass a sequence of permissions (sequence< any >) to check a set of permissions, e.g. for performance reasons. This method quietly returns if the access request is permitted, or throws a suitable AccessControlException otherwise.

        Raises:
            AccessControlException: ``AccessControlException``
        """
        ...

__all__ = ['XAccessControlContext']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.linguistic2
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..beans.property_value import PropertyValue as PropertyValue_c9610c73


class SingleProofreadingError(object):
    """
    Struct Class

    holds a single error found by the proofreader.
    
    **since**
    
        OOo 3.0.1

    See Also:
        `API SingleProofreadingError <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1linguistic2_1_1SingleProofreadingError.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.SingleProofreadingError'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.linguistic2.SingleProofreadingError'
    """Literal Constant ``com.sun.star.linguistic2.SingleProofreadingError``"""

    def __init__(self, aSuggestions: typing.Optional[typing.Tuple[str, ...]] = (), aProperties: typing.Optional[typing.Tuple[PropertyValue_c9610c73, ...]] = (), nErrorStart: typing.Optional[int] = 0, nErrorLength: typing.Optional[int] = 0, nErrorType: typing.Optional[int] = 0, aRuleIdentifier: typing.Optional[str] = '', aShortComment: typing.Optional[str] = '', aFullComment: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            aSuggestions (typing.Tuple[str, ...], optional): aSuggestions value.
            aProperties (typing.Tuple[PropertyValue, ...], optional): aProperties value.
            nErrorStart (int, optional): nErrorStart value.
            nErrorLength (int, optional): nErrorLength value.
            nErrorType (int, optional): nErrorType value.
            aRuleIdentifier (str, optional): aRuleIdentifier value.
            aShortComment (str, optional): aShortComment value.
            aFullComment (str, optional): aFullComment value.
        """
        super().__init__()

        if isinstance(aSuggestions, SingleProofreadingError):
            oth: SingleProofreadingError = aSuggestions
            self.aSuggestions = oth.aSuggestions
            self.aProperties = oth.aProperties
            self.nErrorStart = oth.nErrorStart
            self.nErrorLength = oth.nErrorLength
            self.nErrorType = oth.nErrorType
            self.aRuleIdentifier = oth.aRuleIdentifier
            self.aShortComment = oth.aShortComment
            self.aFullComment = oth.aFullComment
            return

        kargs = {
            "aSuggestions": aSuggestions,
            "aProperties": aProperties,
            "nErrorStart": nErrorStart,
            "nErrorLength": nErrorLength,
            "nErrorType": nErrorType,
            "aRuleIdentifier": aRuleIdentifier,
            "aShortComment": aShortComment,
            "aFullComment": aFullComment,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._a_suggestions = kwargs["aSuggestions"]
        self._a_properties = kwargs["aProperties"]
        self._n_error_start = kwargs["nErrorStart"]
        self._n_error_length = kwargs["nErrorLength"]
        self._n_error_type = kwargs["nErrorType"]
        self._a_rule_identifier = kwargs["aRuleIdentifier"]
        self._a_short_comment = kwargs["aShortComment"]
        self._a_full_comment = kwargs["aFullComment"]


    @property
    def aSuggestions(self) -> typing.Tuple[str, ...]:
        return self._a_suggestions

    @aSuggestions.setter
    def aSuggestions(self, value: typing.Tuple[str, ...]) -> None:
        self._a_suggestions = value

    @property
    def aProperties(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        return self._a_properties

    @aProperties.setter
    def aProperties(self, value: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        self._a_properties = value

    @property
    def nErrorStart(self) -> int:
        return self._n_error_start

    @nErrorStart.setter
    def nErrorStart(self, value: int) -> None:
        self._n_error_start = value

    @property
    def nErrorLength(self) -> int:
        return self._n_error_length

    @nErrorLength.setter
    def nErrorLength(self, value: int) -> None:
        self._n_error_length = value

    @property
    def nErrorType(self) -> int:
        return self._n_error_type

    @nErrorType.setter
    def nErrorType(self, value: int) -> None:
        self._n_error_type = value

    @property
    def aRuleIdentifier(self) -> str:
        return self._a_rule_identifier

    @aRuleIdentifier.setter
    def aRuleIdentifier(self, value: str) -> None:
        self._a_rule_identifier = value

    @property
    def aShortComment(self) -> str:
        return self._a_short_comment

    @aShortComment.setter
    def aShortComment(self, value: str) -> None:
        self._a_short_comment = value

    @property
    def aFullComment(self) -> str:
        return self._a_full_comment

    @aFullComment.setter
    def aFullComment(self, value: str) -> None:
        self._a_full_comment = value


__all__ = ['SingleProofreadingError']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs
from __future__ import annotations
from abc import abstractmethod
from .x_file_picker import XFilePicker as XFilePicker_ec3e0d2d

class XFilePickerControlAccess(XFilePicker_ec3e0d2d):
    """
    Provides access to the controls of a FilePicker.
    
    A FilePicker may contain additional elements according to the needs of the different applications. These additional elements can be addressed by this interface.

    See Also:
        `API XFilePickerControlAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePickerControlAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui.dialogs'
    __ooo_full_ns__: str = 'com.sun.star.ui.dialogs.XFilePickerControlAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.dialogs.XFilePickerControlAccess'

    @abstractmethod
    def enableControl(self, ControlId: int, bEnable: bool) -> None:
        """
        Enables or disables a control.
        
        If TRUE the specified control will be enabled.
        
        If FALSE the specified control will be disabled.
        """
        ...
    @abstractmethod
    def getLabel(self, aControlId: int) -> str:
        """
        Returns the label of the specified element.
        """
        ...
    @abstractmethod
    def getValue(self, aControlId: int, aControlAction: int) -> object:
        """
        Get the value of an additional element within a FilePicker.
        """
        ...
    @abstractmethod
    def setLabel(self, aControlId: int, aLabel: str) -> None:
        """
        Set the label of the specified element.
        
        If the specified element doesn't support setting a label, this method has no effect.
        """
        ...
    @abstractmethod
    def setValue(self, ControlId: int, aControlAction: int, aValue: object) -> None:
        """
        Set the value of an additional element within a FilePicker.
        """
        ...

__all__ = ['XFilePickerControlAccess']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_desktop_task import XDesktopTask as XDesktopTask_bb4c0bd8
from .x_frames_supplier import XFramesSupplier as XFramesSupplier_e12a0d1d
from .x_window_arranger import XWindowArranger as XWindowArranger_e1820d15
if typing.TYPE_CHECKING:
    from ..awt.point import Point as Point_5fb2085e
    from ..awt.size import Size as Size_576707ef

class DesktopTask(XPropertySet_bc180bfa, XDesktopTask_bb4c0bd8, XFramesSupplier_e12a0d1d, XWindowArranger_e1820d15):
    """
    Service Class

    use the Frame service instead of this
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API DesktopTask <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1DesktopTask.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.DesktopTask'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def IsAlwaysVisible(self) -> bool:
        """
        """
        ...

    @abstractproperty
    def IsDesktop(self) -> bool:
        """
        """
        ...

    @abstractproperty
    def IsFloating(self) -> bool:
        """
        """
        ...

    @abstractproperty
    def IsVisible(self) -> bool:
        """
        use th visible state of the frame container window instead of this
        """
        ...

    @abstractproperty
    def Position(self) -> Point_5fb2085e:
        """
        use the position of the frame container window instead of this
        """
        ...

    @abstractproperty
    def Size(self) -> Size_576707ef:
        """
        use the size of the frame container window instead of this
        """
        ...

    @abstractproperty
    def Title(self) -> str:
        """
        use property Frame.Title instead of that
        """
        ...


__all__ = ['DesktopTask']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.submission
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_submission_veto_listener import XSubmissionVetoListener as XSubmissionVetoListener_18e1149e
    from ...task.x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class XSubmission(XInterface_8f010a43):
    """
    is implemented by components which support submitting data.

    See Also:
        `API XSubmission <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1submission_1_1XSubmission.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.submission'
    __ooo_full_ns__: str = 'com.sun.star.form.submission.XSubmission'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.submission.XSubmission'

    @abstractmethod
    def addSubmissionVetoListener(self, listener: XSubmissionVetoListener_18e1149e) -> None:
        """
        registers the given listener to be notified when a submission occurs

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def removeSubmissionVetoListener(self, listener: XSubmissionVetoListener_18e1149e) -> None:
        """
        revokes a listener which has previously been registered to be notified when a submission occurs

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def submit(self) -> None:
        """
        tells the component to submit data

        Raises:
            com.sun.star.util.VetoException: ``VetoException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def submitWithInteraction(self, aHandler: XInteractionHandler_bf80e51) -> None:
        """
        tells the component to submit data

        Raises:
            com.sun.star.util.VetoException: ``VetoException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...

__all__ = ['XSubmission']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_storable import XStorable as XStorable_998f0aa7
    from ..ucb.x_content import XContent as XContent_79db0975

class XDocumentTemplates(XInterface_8f010a43):
    """
    provides a high level API to organize document templates
    
    Template information is saved as links to the original content and organized in groups. This data should be persistent and can be updated by calling special method XDocumentTemplates.update(). A real implementation of this interface can do that on top of a ucb content provider. Method XDocumentTemplates.getContent() force that.

    See Also:
        `API XDocumentTemplates <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XDocumentTemplates.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XDocumentTemplates'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XDocumentTemplates'

    @abstractmethod
    def addGroup(self, GroupName: str) -> bool:
        """
        creates a new group
        """
        ...
    @abstractmethod
    def addTemplate(self, GroupName: str, TemplateName: str, SourceURL: str) -> bool:
        """
        creates the template with the given name in the given group using the given URL
        """
        ...
    @abstractmethod
    def getContent(self) -> XContent_79db0975:
        """
        provides access to the root of internal used hierarchy
        
        This content can be used for accessing the groups directly.
        """
        ...
    @abstractmethod
    def removeGroup(self, GroupName: str) -> bool:
        """
        remove an existing group
        """
        ...
    @abstractmethod
    def removeTemplate(self, GroupName: str, TemplateName: str) -> bool:
        """
        remove a template from specified group
        """
        ...
    @abstractmethod
    def renameGroup(self, OldGroupName: str, NewGroupName: str) -> bool:
        """
        rename an existing group
        """
        ...
    @abstractmethod
    def renameTemplate(self, GroupName: str, OldTemplateName: str, NewTemplateName: str) -> bool:
        """
        rename a template inside specified group
        """
        ...
    @abstractmethod
    def storeTemplate(self, GroupName: str, TemplateName: str, Storable: XStorable_998f0aa7) -> bool:
        """
        creates the template with the given name in the given group using the data from the storable
        """
        ...
    @abstractmethod
    def update(self) -> None:
        """
        force an update for internal structures
        
        Because the templates are well known by links and not as direct content they can be outdated. An update force actualization of that to find wrong links.
        """
        ...

__all__ = ['XDocumentTemplates']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.deployment
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_package_manager import XPackageManager as XPackageManager_2bc50f08

class XPackageManagerFactory(ABC):
    """
    The XPackageManagerFactory interface is used to obtain XPackageManager instances.
    
    You have to use the singleton  /singletons/com.sun.star.deployment.thePackageManagerFactory  exclusively.
    
    **since**
    
        OOo 2.0
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XPackageManagerFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1deployment_1_1XPackageManagerFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.deployment'
    __ooo_full_ns__: str = 'com.sun.star.deployment.XPackageManagerFactory'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.deployment.XPackageManagerFactory'

    @abstractmethod
    def getPackageManager(self, context: str) -> XPackageManager_2bc50f08:
        """
        Method to create (or reusing and already existing) XPackageManager object to add or remove UNO packages persistently.
        
        Packages for context strings \"user\" and \"shared\" will be registered and revoked persistently.
        
        Context strings other than \"user\", \"shared\" will last in an com.sun.star.lang.IllegalArgumentException.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XPackageManagerFactory']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.uri
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ..util.x_macro_expander import XMacroExpander as XMacroExpander_c8360c47

class XVndSunStarExpandUrl(ABC):
    """
    represents absolute “vnd.sun.star.expand” URLs.
    
    These URLs are of the form   vnd-sun-star-expand-url = \"VND.SUN.STAR.EXPAND:\" opaque_partwhere the opaque_part is a UTF-8 string as described in Bootstrap Arguments and Micro Deployment. See RFC 3986 RFC 2234 for details.
    
    **since**
    
        OOo 2.3

    See Also:
        `API XVndSunStarExpandUrl <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1uri_1_1XVndSunStarExpandUrl.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.uri'
    __ooo_full_ns__: str = 'com.sun.star.uri.XVndSunStarExpandUrl'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.uri.XVndSunStarExpandUrl'

    @abstractmethod
    def expand(self, expander: XMacroExpander_c8360c47) -> str:
        """
        returns the expanded content of this URL.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XVndSunStarExpandUrl']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt


class WindowAttribute(object):
    """
    Const Class

    These values are used to specify the decorations of a window.
    
    IMPORTANT: These constants have to be disjunct with constants in VclWindowPeerAttribute.

    See Also:
        `API WindowAttribute <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1WindowAttribute.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.WindowAttribute'
    __ooo_type_name__: str = 'const'

    SHOW = 1
    """
    specifies that the window is initially visible.
    """
    FULLSIZE = 2
    """
    specifies that the window fills the complete desktop area.
    
    This applies only to top windows.
    """
    OPTIMUMSIZE = 4
    """
    specifies that the window is optimum size.
    
    This applies only to top windows.
    """
    MINSIZE = 8
    """
    specifies that the window is minimum size.
    
    This applies only to top windows.
    """
    BORDER = 16
    """
    specifies that the window has visible borders.
    
    This applies only to top windows.
    """
    SIZEABLE = 32
    """
    specifies that the size of the window can be changed by the user.
    
    This applies only to top windows.
    """
    MOVEABLE = 64
    """
    specifies that the window can be moved by the user.
    
    This applies only to top windows.
    """
    CLOSEABLE = 128
    """
    specifies that the window can be closed by the user.
    
    This applies only to top windows.
    """
    SYSTEMDEPENDENT = 256
    """
    specifies that the window should support the com.sun.star.awt.XSystemDependentWindowPeer interface.
    
    This flag may be ignored, but in this case no system-dependent extension works.
    """
    NODECORATION = 512
    """
    specifies that the window should have no decoration.
    """

__all__ = ['WindowAttribute']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.x_window import XWindow as XWindow_713b0924

class XToolbarController(XInterface_8f010a43):
    """
    is an abstract service for a component which offers a more complex user interface to users within a toolbar.
    
    A generic toolbar function is represented as a button which has a state (enabled,disabled and selected, not selected). A toolbar controller can be added to a toolbar and provide information or functions with a more sophisticated user interface.A typical example for toolbar controller is a font chooser on a toolbar. It provides all available fonts in a dropdown box and shows the current chosen font.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XToolbarController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XToolbarController.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XToolbarController'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XToolbarController'

    @abstractmethod
    def click(self) -> None:
        """
        notifies a component that a single click has been made on the toolbar item.
        """
        ...
    @abstractmethod
    def createItemWindow(self, Parent: XWindow_713b0924) -> XWindow_713b0924:
        """
        requests to create an item window which can be added to the toolbar.
        """
        ...
    @abstractmethod
    def createPopupWindow(self) -> XWindow_713b0924:
        """
        requests to create a pop-up window for additional functions.
        """
        ...
    @abstractmethod
    def doubleClick(self) -> None:
        """
        notifies a component that a double click has been made on the toolbar item.
        """
        ...
    @abstractmethod
    def execute(self, KeyModifier: int) -> None:
        """
        provides a function to execute the command which is bound to the toolbar controller.
        
        This function is usually called by a toolbar implementation when a user clicked on a toolbar button or pressed enter on the keyboard when the item has the input focus.
        """
        ...

__all__ = ['XToolbarController']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.task.async_job import AsyncJob as AsyncJob
with suppress(ImportError):
    from ...dyn.task.classified_interaction_request import ClassifiedInteractionRequest as ClassifiedInteractionRequest
with suppress(ImportError):
    from ...dyn.task.document_ms_password_request import DocumentMSPasswordRequest as DocumentMSPasswordRequest
with suppress(ImportError):
    from ...dyn.task.document_ms_password_request2 import DocumentMSPasswordRequest2 as DocumentMSPasswordRequest2
with suppress(ImportError):
    from ...dyn.task.document_macro_confirmation_request import DocumentMacroConfirmationRequest as DocumentMacroConfirmationRequest
with suppress(ImportError):
    from ...dyn.task.document_password_request import DocumentPasswordRequest as DocumentPasswordRequest
with suppress(ImportError):
    from ...dyn.task.document_password_request2 import DocumentPasswordRequest2 as DocumentPasswordRequest2
with suppress(ImportError):
    from ...dyn.task.error_code_io_exception import ErrorCodeIOException as ErrorCodeIOException
with suppress(ImportError):
    from ...dyn.task.error_code_request import ErrorCodeRequest as ErrorCodeRequest
with suppress(ImportError):
    from ...dyn.task.interaction_classification import InteractionClassification as InteractionClassification
with suppress(ImportError):
    from ...dyn.task.interaction_handler import InteractionHandler as InteractionHandler
with suppress(ImportError):
    from ...dyn.task.interaction_request_string_resolver import InteractionRequestStringResolver as InteractionRequestStringResolver
with suppress(ImportError):
    from ...dyn.task.job import Job as Job
with suppress(ImportError):
    from ...dyn.task.job_executor import JobExecutor as JobExecutor
with suppress(ImportError):
    from ...dyn.task.master_password_request import MasterPasswordRequest as MasterPasswordRequest
with suppress(ImportError):
    from ...dyn.task.no_master_exception import NoMasterException as NoMasterException
with suppress(ImportError):
    from ...dyn.task.office_restart_manager import OfficeRestartManager as OfficeRestartManager
with suppress(ImportError):
    from ...dyn.task.pdf_export_exception import PDFExportException as PDFExportException
with suppress(ImportError):
    from ...dyn.task.password_container import PasswordContainer as PasswordContainer
with suppress(ImportError):
    from ...dyn.task.password_container_interaction_handler import PasswordContainerInteractionHandler as PasswordContainerInteractionHandler
with suppress(ImportError):
    from ...dyn.task.password_request import PasswordRequest as PasswordRequest
with suppress(ImportError):
    from ...dyn.task.password_request_mode import PasswordRequestMode as PasswordRequestMode
with suppress(ImportError):
    from ...dyn.task.status_indicator_factory import StatusIndicatorFactory as StatusIndicatorFactory
with suppress(ImportError):
    from ...dyn.task.unsupported_overwrite_request import UnsupportedOverwriteRequest as UnsupportedOverwriteRequest
with suppress(ImportError):
    from ...dyn.task.url_record import UrlRecord as UrlRecord
with suppress(ImportError):
    from ...dyn.task.user_record import UserRecord as UserRecord
with suppress(ImportError):
    from ...dyn.task.x_abort_channel import XAbortChannel as XAbortChannel
with suppress(ImportError):
    from ...dyn.task.x_async_job import XAsyncJob as XAsyncJob
with suppress(ImportError):
    from ...dyn.task.x_interaction_abort import XInteractionAbort as XInteractionAbort
with suppress(ImportError):
    from ...dyn.task.x_interaction_approve import XInteractionApprove as XInteractionApprove
with suppress(ImportError):
    from ...dyn.task.x_interaction_ask_later import XInteractionAskLater as XInteractionAskLater
with suppress(ImportError):
    from ...dyn.task.x_interaction_continuation import XInteractionContinuation as XInteractionContinuation
with suppress(ImportError):
    from ...dyn.task.x_interaction_disapprove import XInteractionDisapprove as XInteractionDisapprove
with suppress(ImportError):
    from ...dyn.task.x_interaction_handler import XInteractionHandler as XInteractionHandler
with suppress(ImportError):
    from ...dyn.task.x_interaction_handler2 import XInteractionHandler2 as XInteractionHandler2
with suppress(ImportError):
    from ...dyn.task.x_interaction_password import XInteractionPassword as XInteractionPassword
with suppress(ImportError):
    from ...dyn.task.x_interaction_password2 import XInteractionPassword2 as XInteractionPassword2
with suppress(ImportError):
    from ...dyn.task.x_interaction_request import XInteractionRequest as XInteractionRequest
with suppress(ImportError):
    from ...dyn.task.x_interaction_request_string_resolver import XInteractionRequestStringResolver as XInteractionRequestStringResolver
with suppress(ImportError):
    from ...dyn.task.x_interaction_retry import XInteractionRetry as XInteractionRetry
with suppress(ImportError):
    from ...dyn.task.x_job import XJob as XJob
with suppress(ImportError):
    from ...dyn.task.x_job_executor import XJobExecutor as XJobExecutor
with suppress(ImportError):
    from ...dyn.task.x_job_listener import XJobListener as XJobListener
with suppress(ImportError):
    from ...dyn.task.x_master_password_handling import XMasterPasswordHandling as XMasterPasswordHandling
with suppress(ImportError):
    from ...dyn.task.x_master_password_handling2 import XMasterPasswordHandling2 as XMasterPasswordHandling2
with suppress(ImportError):
    from ...dyn.task.x_password_container import XPasswordContainer as XPasswordContainer
with suppress(ImportError):
    from ...dyn.task.x_password_container2 import XPasswordContainer2 as XPasswordContainer2
with suppress(ImportError):
    from ...dyn.task.x_restart_manager import XRestartManager as XRestartManager
with suppress(ImportError):
    from ...dyn.task.x_status_indicator import XStatusIndicator as XStatusIndicator
with suppress(ImportError):
    from ...dyn.task.x_status_indicator_factory import XStatusIndicatorFactory as XStatusIndicatorFactory
with suppress(ImportError):
    from ...dyn.task.x_status_indicator_supplier import XStatusIndicatorSupplier as XStatusIndicatorSupplier
with suppress(ImportError):
    from ...dyn.task.x_url_container import XUrlContainer as XUrlContainer
with suppress(ImportError):
    from ...dyn.task.the_job_executor import theJobExecutor as theJobExecutor



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.graphic
from __future__ import annotations
from .x_graphic_provider import XGraphicProvider as XGraphicProvider_b5b0e47

class GraphicProvider(XGraphicProvider_b5b0e47):
    """
    Service Class

    Central service of the Graphic API that gives access to graphics of any kind.
    
    This service allows to load graphics from and to store graphics to any location. The one and only interface that has to be implemented is the XGraphicProvider interface, that exposes the necessary methods for loading and storing the graphic contents and descriptors

    See Also:
        `API GraphicProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1graphic_1_1GraphicProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.graphic'
    __ooo_full_ns__: str = 'com.sun.star.graphic.GraphicProvider'
    __ooo_type_name__: str = 'service'


__all__ = ['GraphicProvider']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XGridFieldDataSupplier(XInterface_8f010a43):
    """
    provides access to the data of a GridControl
    
    You can retrieve the data type information and the data in a row.
    
    This interface allows to retrieve data even for rows which are not current, which is quite useful, as normally, you can't affect the current row in a grid control without moving the cursor of the underlying com.sun.star.form.component.DataForm.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XGridFieldDataSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XGridFieldDataSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.XGridFieldDataSupplier'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.XGridFieldDataSupplier'

    @abstractmethod
    def queryFieldData(self, nRow: int, xType: object) -> typing.Tuple[object, ...]:
        """
        retrieves the actual column data for the given row
        
        If a column does not support the requested type, NULL is returned at the respective position.
        """
        ...
    @abstractmethod
    def queryFieldDataType(self, xType: object) -> typing.Tuple[bool, ...]:
        """
        checks whether or not the content of the grid's columns can be retrieved in the requested format.
        
        Not every cell content can be retrieved in every representation. For example, in a text column, you usually won't be able to retrieve the content as double.To check if the type you need is supported by the columns, use this method.
        """
        ...

__all__ = ['XGridFieldDataSupplier']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.accessibility


class AccessibleRelationType(object):
    """
    Const Class

    Collection of relation types.
    
    This list of constants defines the available types of relations that are usable by AccessibleRelation.
    
    We are using constants instead of a more typesafe enum. The reason for this is that IDL enums may not be extended. Therefore, in order to include future extensions to the set of roles we have to use constants here.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleRelationType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1accessibility_1_1AccessibleRelationType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.AccessibleRelationType'
    __ooo_type_name__: str = 'const'

    INVALID = 0
    """
    Invalid relation type.
    
    Indicates an invalid relation type. This is used to indicate that a retrieval method could not find a requested relation.
    """
    CONTENT_FLOWS_FROM = 1
    """
    Content-flows-from relation.
    
    Indicates a content flow between the related objects.
    """
    CONTENT_FLOWS_TO = 2
    """
    Content-flows-to relation.
    
    Indicates a content flow between the related objects.
    """
    CONTROLLED_BY = 3
    """
    Controlled-by relation type.
    
    Indicates an object is controlled by one or more target objects.
    """
    CONTROLLER_FOR = 4
    """
    Controller-for relation type.
    
    Indicates an object is a controller for one or more target objects.
    """
    LABEL_FOR = 5
    """
    Label-for relation type.
    
    Indicates an object is a label for one or more target objects.
    """
    LABELED_BY = 6
    """
    Labeled-by relation type.
    
    Indicates an object is labeled by one or more target objects.
    """
    MEMBER_OF = 7
    """
    Member-of relation type.
    
    Indicates an object is a member of a group of one or more target objects.
    """
    SUB_WINDOW_OF = 8
    """
    Sub-Window-of relation type.
    
    With this relation you can realize an alternative parent-child relationship. The target of the relation contains the parent window. Note that there is no relation that points the other way, from the parent window to the child window.
    """
    NODE_CHILD_OF = 9
    """
    Node-Child-of relation type.
    
    Indicates an object is a cell in a tree or tree table which is displayed because a cell in the same column is expanded and identifies that cell.
    
    **since**
    
        OOo 3.0
    """
    DESCRIBED_BY = 10
    """
    Described-by relation type.
    
    Indicates an object is described by the target object.
    
    **since**
    
        OOo 3.5
    """

__all__ = ['AccessibleRelationType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6

class XMembersAccess(XNameAccess_e2ab0cf6):
    """
    is used to access named members in a data pilot source level collection.

    See Also:
        `API XMembersAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XMembersAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XMembersAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XMembersAccess'

    @abstractmethod
    def getLocaleIndependentElementNames(self) -> typing.Tuple[str, ...]:
        """
        returns names of data pilot members in a locale independent notation.
        
        Specifically date values are represented in an ISO 8601 YYYY-MM-DD notation and date+time as YYYY-MM-DD HH:MM:SS, whereas the strings returned by com.sun.star.container.XNameAccess.getElementNames() may represent these in a locale dependent or user formatted notation such as MM/DD/YY or DD.MM.YYYY or other.
        
        The names returned by this function can NOT be used in calls to com.sun.star.container.XNameAccess.getByName(). However, the order returned in two immediately consecutive calls to getElementNames() and getLocaleIndependentElementNames() maps to the same elements in order.
        """
        ...

__all__ = ['XMembersAccess']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.sax
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...lang.locale import Locale as Locale_70d308fa
    from .input_source import InputSource as InputSource_c88c0c54
    from .x_entity_resolver import XEntityResolver as XEntityResolver_fcf10dfa
    from .x_error_handler import XErrorHandler as XErrorHandler_e0860cf3
    from .x_fast_document_handler import XFastDocumentHandler as XFastDocumentHandler_454c0fb6
    from .x_fast_namespace_handler import XFastNamespaceHandler as XFastNamespaceHandler_549c1004
    from .x_fast_token_handler import XFastTokenHandler as XFastTokenHandler_17510e78

class XFastParser(XInterface_8f010a43):
    """
    specifies a SAX parser that uses integer values for known XML names (elements, attributes and attribute values).
    
    The parser also handles namespaces and allows to have individual contexts for each XML element.
    
    Before parsing is possible you have to set your XFastDocumentHandler using setFastDocumentHandler().
    
    Parsing starts with calling parseStream(). If the parser finds a valid XML file with the given InputSource, it calls XFastDocumentHandler.startDocument() first.
    
    This parser generates either \"fast\" events that use integer token values for namespaces, elements and attributes or \"unknown\" events for elements that are unknown.
    
    A namespace is unknown if the namespace URL was not registered with registerNamespace().
    
    An element is unknown if no XFastTokenHandler is set or if the XFastTokenHandler does not return a valid identifier for the elements local name. An element is also unknown if the elements local name is known but it uses a namespace that is unknown.
    
    Setting a XFastTokenHandler with setTokenHandler() is optional, but without a XFastTokenHandler you will only get unknown sax events. This can be useful if you are only interested in the namespace handling and/or the context feature.
    
    For each element the parser sends a create child element event to the elements parent context by calling XFastContextHandler.createFastChildContext() for known elements or XFastContextHandler.createUnknownChildContext() for unknown elements. The parent context for the root element is the XFastDocumentHandler itself.
    
    If the parent context returns an empty reference, no further events for the element and all of its children are created.
    
    If a valid context is returned this context gets a start event by a call to XFastContextHandler.startFastElement() for known elements or XFastContextHandler.startUnknownElement() for unknown elements.
    
    After processing all its child elements the context gets an end event by a call to XFastContextHandler.endFastElement() for known elements or XFastContextHandler.endUnknownElement() for unknown elements.
    
    It is valid to return one instance of XFastContextHandler more than once. It is even possible to only use the XFastDocumentHandler by always returning a reference to itself for each create child context event.
    
    After the last element is processed the parser generates an end document event at the XFastDocumentHandler by calling XFastDocumentHandler.endDocument().
    
    **since**
    
        LibreOffice 7.1

    See Also:
        `API XFastParser <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XFastParser.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.sax'
    __ooo_full_ns__: str = 'com.sun.star.xml.sax.XFastParser'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.sax.XFastParser'

    @abstractmethod
    def getNamespaceURL(self, prefix: str) -> str:
        """
        Gets the namespace url string.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def parseStream(self, aInputSource: InputSource_c88c0c54) -> None:
        """
        parses an XML document from a stream.
        
        Set the desired handlers before calling this method.

        Raises:
            SAXException: ``SAXException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def registerNamespace(self, NamespaceURL: str, NamespaceToken: int) -> None:
        """
        registers a known namespace url with the given integer token.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def setCustomEntityNames(self, replacements: typing.Tuple[typing.Tuple[str, str], ...]) -> None:
        """
        Simulate a DTD file.
        
        Will allow to use customized entity references like ∞ .
        
        **since**
        
            LibreOffice 7.1
        """
        ...
    @abstractmethod
    def setEntityResolver(self, Resolver: XEntityResolver_fcf10dfa) -> None:
        """
        allows an application to register a DTD-Handler.
        """
        ...
    @abstractmethod
    def setErrorHandler(self, Handler: XErrorHandler_e0860cf3) -> None:
        """
        allows an application to register an error event handler.
        
        Note that the error handler can throw an exception when an error or warning occurs. Note that an exception is thrown by the parser when an unrecoverable (fatal) error occurs.
        """
        ...
    @abstractmethod
    def setFastDocumentHandler(self, Handler: XFastDocumentHandler_454c0fb6) -> None:
        """
        Application must register a document event handler to get sax events for the parsed stream.
        """
        ...
    @abstractmethod
    def setLocale(self, locale: Locale_70d308fa) -> None:
        """
        sets a locale specified for localization of warnings and error messages.
        
        Set the language of the error messages. Useful when the parsing errors will be presented to the user.
        """
        ...
    @abstractmethod
    def setNamespaceHandler(self, Handler: XFastNamespaceHandler_549c1004) -> None:
        """
        """
        ...
    @abstractmethod
    def setTokenHandler(self, Handler: XFastTokenHandler_17510e78) -> None:
        """
        must be registered to translate known XML names to integer tokens.
        """
        ...

__all__ = ['XFastParser']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.bridge.bridge import Bridge as Bridge
from ...lo.bridge.bridge_exists_exception import BridgeExistsException as BridgeExistsException
from ...lo.bridge.bridge_factory import BridgeFactory as BridgeFactory
from ...lo.bridge.iiop_bridge import IiopBridge as IiopBridge
from ...lo.bridge.invalid_protocol_change_exception import InvalidProtocolChangeException as InvalidProtocolChangeException
from ...lo.bridge.model_dependent import ModelDependent as ModelDependent
from ...lo.bridge.ole_application_registration import OleApplicationRegistration as OleApplicationRegistration
from ...lo.bridge.ole_bridge_supplier import OleBridgeSupplier as OleBridgeSupplier
from ...lo.bridge.ole_bridge_supplier2 import OleBridgeSupplier2 as OleBridgeSupplier2
from ...lo.bridge.ole_bridge_supplier_var1 import OleBridgeSupplierVar1 as OleBridgeSupplierVar1
from ...lo.bridge.ole_object_factory import OleObjectFactory as OleObjectFactory
from ...lo.bridge.protocol_property import ProtocolProperty as ProtocolProperty
from ...lo.bridge.uno_url_resolver import UnoUrlResolver as UnoUrlResolver
from ...lo.bridge.urp_bridge import UrpBridge as UrpBridge
from ...lo.bridge.x_bridge import XBridge as XBridge
from ...lo.bridge.x_bridge_factory import XBridgeFactory as XBridgeFactory
from ...lo.bridge.x_bridge_factory2 import XBridgeFactory2 as XBridgeFactory2
from ...lo.bridge.x_bridge_supplier import XBridgeSupplier as XBridgeSupplier
from ...lo.bridge.x_bridge_supplier2 import XBridgeSupplier2 as XBridgeSupplier2
from ...lo.bridge.x_instance_provider import XInstanceProvider as XInstanceProvider
from ...lo.bridge.x_protocol_properties import XProtocolProperties as XProtocolProperties
from ...lo.bridge.x_uno_url_resolver import XUnoUrlResolver as XUnoUrlResolver



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt


class VclWindowPeerAttribute(object):
    """
    Const Class

    specifies attributes for the VCL window implementation.
    
    IMPORTANT: These constants have to be disjunct with constants in WindowAttribute.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API VclWindowPeerAttribute <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1VclWindowPeerAttribute.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.VclWindowPeerAttribute'
    __ooo_type_name__: str = 'const'

    HSCROLL = 256
    VSCROLL = 512
    LEFT = 1024
    CENTER = 2048
    RIGHT = 4096
    SPIN = 8192
    SORT = 16384
    DROPDOWN = 32768
    DEFBUTTON = 65536
    READONLY = 262144
    CLIPCHILDREN = 524288
    NOBORDER = 1048576
    GROUP = 2097152
    OK = 4194304
    OK_CANCEL = 8388608
    YES_NO = 16777216
    YES_NO_CANCEL = 33554432
    RETRY_CANCEL = 67108864
    DEF_OK = 134217728
    DEF_CANCEL = 268435456
    DEF_RETRY = 536870912
    DEF_YES = 1073741824
    DEF_NO = -2147483648
    NOLABEL = 536870912
    AUTOHSCROLL = 1073741824
    AUTOVSCROLL = -2147483648

__all__ = ['VclWindowPeerAttribute']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_completed_connection import XCompletedConnection as XCompletedConnection_98a0e46
from .x_database_access import XDatabaseAccess as XDatabaseAccess_c47a0c00
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..util.x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier_3afb0fb7

class DatabaseAccess(XPropertySet_bc180bfa, XCompletedConnection_98a0e46, XDatabaseAccess_c47a0c00):
    """
    Service Class

    specifies a component, which controls DatabaseAccessConnections and acts like a shared DataSource.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API DatabaseAccess <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DatabaseAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DatabaseAccess'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ConnectInfo(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        is a list of arbitrary string tag/value pairs as connection arguments; normally at least a \"user\" and \"password\" property should be included.
        """
        ...

    @abstractproperty
    def TableFilter(self) -> typing.Tuple[str, ...]:
        """
        defines a list of tables, on which the bean should have it's focus.
        
        If empty, all tables are rejected.
        """
        ...

    @abstractproperty
    def TableTypeFilter(self) -> typing.Tuple[str, ...]:
        """
        defines a list of table types, on which the bean should have it's focus.
        
        If empty, all tables types are rejected.
        """
        ...

    @abstractproperty
    def ConnectURL(self) -> str:
        """
        indicates a database url of the form  jdbc:subprotocol:subname or  sdbc:subprotocol:subname
        """
        ...

    @abstractproperty
    def IsPasswordRequired(self) -> bool:
        """
        indicates that a password is always necessary.
        """
        ...

    @abstractproperty
    def IsReadOnly(self) -> bool:
        """
        determines whether modifications on the data access bean are allowed or not.
        """
        ...

    @abstractproperty
    def NumberFormatsSupplier(self) -> XNumberFormatsSupplier_3afb0fb7:
        """
        provides an object for formatting numbers.
        """
        ...

    @abstractproperty
    def Title(self) -> str:
        """
        is the title of the bean.
        """
        ...

    @abstractproperty
    def URL(self) -> str:
        """
        is the URL of the bean.
        """
        ...


__all__ = ['DatabaseAccess']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..geometry.affine_matrix2_d import AffineMatrix2D as AffineMatrix2D_ff040da8
from .stroke_attributes import StrokeAttributes as StrokeAttributes_2dd10f65
from .x_bitmap import XBitmap as XBitmap_b1b70b7b
from .x_parametric_poly_polygon2_d import XParametricPolyPolygon2D as XParametricPolyPolygon2D_b3511228


class Texture(object):
    """
    Struct Class

    Contains all information needed to define a texture.
    
    This structure contains all information necessary to define a texture. A texture describes the filled area of polygonal shapes, providing its own transformation matrix, repeat mode, and transparency.
    
    To achieve uniformity, if this texture has a bitmap set, it is scaled in such a way that it will cover the same [0,1]x[0,1] box as the hatch and the gradient. The transformation member can then be used to scale the complete texture as it fits suit.
    
    **since**
    
        OOo 2.0

    See Also:
        `API Texture <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1Texture.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.Texture'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.rendering.Texture'
    """Literal Constant ``com.sun.star.rendering.Texture``"""

    def __init__(self, AffineTransform: typing.Optional[AffineMatrix2D_ff040da8] = UNO_NONE, Alpha: typing.Optional[float] = 0.0, NumberOfHatchPolygons: typing.Optional[int] = 0, Bitmap: typing.Optional[XBitmap_b1b70b7b] = None, Gradient: typing.Optional[XParametricPolyPolygon2D_b3511228] = None, Hatching: typing.Optional[XParametricPolyPolygon2D_b3511228] = None, HatchAttributes: typing.Optional[StrokeAttributes_2dd10f65] = UNO_NONE, RepeatModeX: typing.Optional[int] = 0, RepeatModeY: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            AffineTransform (AffineMatrix2D, optional): AffineTransform value.
            Alpha (float, optional): Alpha value.
            NumberOfHatchPolygons (int, optional): NumberOfHatchPolygons value.
            Bitmap (XBitmap, optional): Bitmap value.
            Gradient (XParametricPolyPolygon2D, optional): Gradient value.
            Hatching (XParametricPolyPolygon2D, optional): Hatching value.
            HatchAttributes (StrokeAttributes, optional): HatchAttributes value.
            RepeatModeX (int, optional): RepeatModeX value.
            RepeatModeY (int, optional): RepeatModeY value.
        """
        super().__init__()

        if isinstance(AffineTransform, Texture):
            oth: Texture = AffineTransform
            self.AffineTransform = oth.AffineTransform
            self.Alpha = oth.Alpha
            self.NumberOfHatchPolygons = oth.NumberOfHatchPolygons
            self.Bitmap = oth.Bitmap
            self.Gradient = oth.Gradient
            self.Hatching = oth.Hatching
            self.HatchAttributes = oth.HatchAttributes
            self.RepeatModeX = oth.RepeatModeX
            self.RepeatModeY = oth.RepeatModeY
            return

        kargs = {
            "AffineTransform": AffineTransform,
            "Alpha": Alpha,
            "NumberOfHatchPolygons": NumberOfHatchPolygons,
            "Bitmap": Bitmap,
            "Gradient": Gradient,
            "Hatching": Hatching,
            "HatchAttributes": HatchAttributes,
            "RepeatModeX": RepeatModeX,
            "RepeatModeY": RepeatModeY,
        }
        if kargs["AffineTransform"] is UNO_NONE:
            kargs["AffineTransform"] = None
        if kargs["HatchAttributes"] is UNO_NONE:
            kargs["HatchAttributes"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._affine_transform = kwargs["AffineTransform"]
        self._alpha = kwargs["Alpha"]
        self._number_of_hatch_polygons = kwargs["NumberOfHatchPolygons"]
        self._bitmap = kwargs["Bitmap"]
        self._gradient = kwargs["Gradient"]
        self._hatching = kwargs["Hatching"]
        self._hatch_attributes = kwargs["HatchAttributes"]
        self._repeat_mode_x = kwargs["RepeatModeX"]
        self._repeat_mode_y = kwargs["RepeatModeY"]


    @property
    def AffineTransform(self) -> AffineMatrix2D_ff040da8:
        """
        Texture transformation from texture to primitive space.
        
        This member allows arbitrary transformations of the texture, relative to the textured primitive. Thus, the total transformation from the [0,1]x[0,1] texture space to the device coordinate space is the concatenation of texture, render state, and view state transformation (with only render state and view state transformation being applied to the textured primitive).
        """
        return self._affine_transform

    @AffineTransform.setter
    def AffineTransform(self, value: AffineMatrix2D_ff040da8) -> None:
        self._affine_transform = value

    @property
    def Alpha(self) -> float:
        """
        Overall transparency of the texturing.
        
        The valid range for this value is [0,1], where 0 denotes complete transparency, and 1 denotes fully opaque.
        """
        return self._alpha

    @Alpha.setter
    def Alpha(self, value: float) -> None:
        self._alpha = value

    @property
    def NumberOfHatchPolygons(self) -> int:
        """
        Specifies the number of parameterized polygons used for the texture.
        
        This member specifies the number of polygons the parametric polygon interface is queried. The continuous range [0,1] of the XParametricPolyPolygon.getOutline() method is divided up into numberOfHatchPolygons equal parts, and for everyone of these parts, the start of the interval is plugged into the getOutline method. For example, if numberOfHatchPolygons is 2, then getOutline is called twice, once with 0.0 and once with 0.5. Use this parameter to control the density of the hatching.
        """
        return self._number_of_hatch_polygons

    @NumberOfHatchPolygons.setter
    def NumberOfHatchPolygons(self, value: int) -> None:
        self._number_of_hatch_polygons = value

    @property
    def Bitmap(self) -> XBitmap_b1b70b7b:
        """
        Texture bitmap.
        
        This member can be used together with gradient and hatching.
        
        The bitmap is scaled to a one-by-one rectangle, to cover the same area as both the gradient and the hatching.
        """
        return self._bitmap

    @Bitmap.setter
    def Bitmap(self, value: XBitmap_b1b70b7b) -> None:
        self._bitmap = value

    @property
    def Gradient(self) -> XParametricPolyPolygon2D_b3511228:
        """
        Texture gradient.
        
        This member can be used together with bitmap and hatching. The parametric polygons color value is used to fill the returned polygonal outlines.
        """
        return self._gradient

    @Gradient.setter
    def Gradient(self, value: XParametricPolyPolygon2D_b3511228) -> None:
        self._gradient = value

    @property
    def Hatching(self) -> XParametricPolyPolygon2D_b3511228:
        """
        Texture hatching.
        
        This member can be used together with bitmap and gradient. The parametric polygons color value is used to stroke the returned polygonal outlines.
        """
        return self._hatching

    @Hatching.setter
    def Hatching(self, value: XParametricPolyPolygon2D_b3511228) -> None:
        self._hatching = value

    @property
    def HatchAttributes(self) -> StrokeAttributes_2dd10f65:
        """
        Specifies the stroke attributes used for hatching.
        
        Use 0.0 as the strokeWidth here to indicate hair lines.
        """
        return self._hatch_attributes

    @HatchAttributes.setter
    def HatchAttributes(self, value: StrokeAttributes_2dd10f65) -> None:
        self._hatch_attributes = value

    @property
    def RepeatModeX(self) -> int:
        """
        Repeat mode of the texture, x direction.
        
        The repeat mode is separated into x and y direction, this is the x direction part. Permissible values are from the TexturingMode constants.
        """
        return self._repeat_mode_x

    @RepeatModeX.setter
    def RepeatModeX(self, value: int) -> None:
        self._repeat_mode_x = value

    @property
    def RepeatModeY(self) -> int:
        """
        Repeat mode of the texture, y direction.
        
        The repeat mode is separated into x and y direction, this is the y direction part. Permissible values are from the TexturingMode constants.
        """
        return self._repeat_mode_y

    @RepeatModeY.setter
    def RepeatModeY(self, value: int) -> None:
        self._repeat_mode_y = value


__all__ = ['Texture']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n


class CharType(object):
    """
    Const Class

    Constants to specify the character type that starts a character block.
    
    Character type is Unicode type defined in UnicodeType
    
    Used with XBreakIterator.beginOfCharBlock(), XBreakIterator.endOfCharBlock(), XBreakIterator.nextCharBlock(), XBreakIterator.previousCharBlock()

    See Also:
        `API CharType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1CharType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.CharType'
    __ooo_type_name__: str = 'const'

    ANY_CHAR = 0
    """
    all alpha characters allowed
    """
    UPPERCASE_LETTER = 1
    LOWERCASE_LETTER = 2
    TITLECASE_LETTER = 3
    MODIFIER_LETTER = 4
    OTHER_LETTER = 5
    NON_SPACING_MARK = 6
    ENCLOSING_MARK = 7
    COMBINING_SPACING_MARK = 8
    DECIMAL_DIGIT_NUMBER = 9
    LETTER_NUMBER = 10
    OTHER_NUMBER = 11
    SPACE_SEPARATOR = 12
    LINE_SEPARATOR = 13
    PARAGRAPH_SEPARATOR = 14
    CONTROL = 15
    FORMAT = 16
    PRIVATE_USE = 17
    SURROGATE = 18
    DASH_PUNCTUATION = 19
    START_PUNCTUATION = 20
    END_PUNCTUATION = 21
    CONNECTOR_PUNCTUATION = 22
    OTHER_PUNCTUATION = 23
    MATH_SYMBOL = 24
    CURRENCY_SYMBOL = 25
    MODIFIER_SYMBOL = 26
    OTHER_SYMBOL = 27
    INITIAL_PUNCTUATION = 28
    FINAL_PUNCTUATION = 29
    GENERAL_TYPES_COUNT = 30

__all__ = ['CharType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing.framework
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ...awt.point import Point as Point_5fb2085e
    from ...awt.rectangle import Rectangle as Rectangle_84b109e9
    from ...rendering.x_canvas import XCanvas as XCanvas_b19b0b7a
    from com.sun.star.drawing.framework.BorderType import BorderTypeProto

class XPaneBorderPainter(ABC):
    """
    Paint the border around a rectangular region, typically a pane.
    
    Calling objects have to be able to derive inner bounding boxes of the border from the outer ones and inner ones from outer ones. This conversion and the painting of the border involves three rectangles. The inner and outer bounding box of the border. This is a logical bounding box which the paint methods may paint over. The center box is the third rectangle. This is the actual border between outer and inner background color or bitmap and it is used for placing the bitmaps that are used paint the border. The inner sides and corners are places relative to this center box, i.e. when not further offsets are given then the upper left corner bitmap is painted with its lower right at the upper left of the center box.

    See Also:
        `API XPaneBorderPainter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XPaneBorderPainter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.XPaneBorderPainter'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.framework.XPaneBorderPainter'

    @abstractmethod
    def addBorder(self, sPaneBorderStyleName: str, aRectangle: Rectangle_84b109e9, eBorderType: BorderTypeProto) -> Rectangle_84b109e9:
        """
        Enlarge the given rectangle by the size of the specified part of the border.
        
        This method can be used to convert an inner bounding box into the center box or the outer bounding box.
        """
        ...
    @abstractmethod
    def getCalloutOffset(self, sPaneBorderStyleName: str) -> Point_5fb2085e:
        """
        Return the offset of a call out anchor with respect to the outer border.
        
        This value is used when the call out is realized by a fixed bitmap in order to determine the size and/or location of the outer border for a given call out.
        """
        ...
    @abstractmethod
    def paintBorder(self, sPaneBorderStyleName: str, xCanvas: XCanvas_b19b0b7a, aOuterBorderRectangle: Rectangle_84b109e9, aRepaintArea: Rectangle_84b109e9, sTitle: str) -> None:
        """
        Paint the border around a pane.
        """
        ...
    @abstractmethod
    def paintBorderWithCallout(self, sPaneBorderStyleName: str, xCanvas: XCanvas_b19b0b7a, aOuterBorderRectangle: Rectangle_84b109e9, aRepaintArea: Rectangle_84b109e9, sTitle: str, aCalloutAnchor: Point_5fb2085e) -> None:
        """
        Paint the border around a pane where the border includes a call out that is anchored at the given point.
        
        Most arguments have the same meaning as in the paintBorder().
        """
        ...
    @abstractmethod
    def removeBorder(self, sPaneBorderStyleName: str, aRectangle: Rectangle_84b109e9, eBorderType: BorderTypeProto) -> Rectangle_84b109e9:
        """
        Shrink the given rectangle by the size of the specified part of the border.
        
        This method can be used to convert an outer bounding box into the center box or the inner bounding box.
        """
        ...

__all__ = ['XPaneBorderPainter']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...util.color import Color as Color_68e908c5

class XFilePreview(XInterface_8f010a43):
    """
    FilePicker that support the preview of various file formats should implement this interface.

    See Also:
        `API XFilePreview <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePreview.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui.dialogs'
    __ooo_full_ns__: str = 'com.sun.star.ui.dialogs.XFilePreview'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.dialogs.XFilePreview'

    @abstractmethod
    def getAvailableHeight(self) -> int:
        """
        The method returns the available height of the preview window even if the window is invisible or could not be created.
        
        If a service implementation doesn't support a file preview 0 will be returned.
        """
        ...
    @abstractmethod
    def getAvailableWidth(self) -> int:
        """
        The method returns the available width of the preview window even if the window is invisible or could not be created.
        
        If a service implementation doesn't support a file preview 0 will be returned.
        """
        ...
    @abstractmethod
    def getShowState(self) -> bool:
        """
        Returns the current show state of the preview.
        
        A value of FALSE if the preview window is invisible.
        """
        ...
    @abstractmethod
    def getSupportedImageFormats(self) -> uno.ByteSequence:
        """
        The method returns all image formats that the preview supports.
        """
        ...
    @abstractmethod
    def getTargetColorDepth(self) -> Color_68e908c5:
        """
        The method returns the supported color depth of the target device.
        """
        ...
    @abstractmethod
    def setImage(self, aImageFormat: int, aImage: object) -> None:
        """
        Sets a new image.
        
        If the preview is currently hidden the image will be ignored. An empty any will clear the preview window.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def setShowState(self, bShowState: bool) -> bool:
        """
        Optionally sets the current show state of the preview.
        
        It is possible that the preview implementation doesn't support hiding the preview.
        
        A value of FALSE hides the preview window.
        
        A value of FALSE if the operation fails for any reason or the preview implementation doesn't support hiding the preview.
        """
        ...

__all__ = ['XFilePreview']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.reflection
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_idl_member import XIdlMember as XIdlMember_e3400cfc
if typing.TYPE_CHECKING:
    from .x_idl_class import XIdlClass as XIdlClass_d63a0c9a
    from com.sun.star.reflection.FieldAccessMode import FieldAccessModeProto

class XIdlField2(XIdlMember_e3400cfc):
    """
    Reflects an IDL interface attribute, enum or compound type (i.e.
    
    struct/exception) member.

    See Also:
        `API XIdlField2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlField2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XIdlField2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XIdlField2'

    @abstractmethod
    def get(self, obj: object) -> object:
        """
        Gets the value of the reflected field from the given object, i.e.
        
        an interface, enum or compound type (struct/exception). For enums, the given object is ignored; the returned value reflects the constant enum 32-bit value.
        
        When setting an interface attribute raises a non com.sun.star.uno.RuntimeException, it is wrapped in a com.sun.star.lang.WrappedTargetRuntimeException.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getAccessMode(self) -> FieldAccessModeProto:
        """
        Returns the access mode of the field, i.e.
        
        read-write, read-only or write-only (access mode \"const\" is deprecated).
        """
        ...
    @abstractmethod
    def getType(self) -> XIdlClass_d63a0c9a:
        """
        Returns the type of the field.
        """
        ...
    @abstractmethod
    def set(self, obj: object, value: object) -> None:
        """
        Sets the value of the reflected field of the given object, i.e.
        
        an interface or compound type (struct/exception).
        
        When setting an interface attribute raises a non com.sun.star.uno.RuntimeException, it is wrapped in a com.sun.star.lang.WrappedTargetRuntimeException.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.IllegalAccessException: ``IllegalAccessException``
        """
        ...

__all__ = ['XIdlField2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.dom
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class NodeType(metaclass=UnoEnumMeta, type_name="com.sun.star.xml.dom.NodeType", name_space="com.sun.star.xml.dom"):
        """Dynamically created class that represents ``com.sun.star.xml.dom.NodeType`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.xml.dom.NodeType import ATTRIBUTE_NODE as NODE_TYPE_ATTRIBUTE_NODE
        from com.sun.star.xml.dom.NodeType import CDATA_SECTION_NODE as NODE_TYPE_CDATA_SECTION_NODE
        from com.sun.star.xml.dom.NodeType import COMMENT_NODE as NODE_TYPE_COMMENT_NODE
        from com.sun.star.xml.dom.NodeType import DOCUMENT_FRAGMENT_NODE as NODE_TYPE_DOCUMENT_FRAGMENT_NODE
        from com.sun.star.xml.dom.NodeType import DOCUMENT_NODE as NODE_TYPE_DOCUMENT_NODE
        from com.sun.star.xml.dom.NodeType import DOCUMENT_TYPE_NODE as NODE_TYPE_DOCUMENT_TYPE_NODE
        from com.sun.star.xml.dom.NodeType import ELEMENT_NODE as NODE_TYPE_ELEMENT_NODE
        from com.sun.star.xml.dom.NodeType import ENTITY_NODE as NODE_TYPE_ENTITY_NODE
        from com.sun.star.xml.dom.NodeType import ENTITY_REFERENCE_NODE as NODE_TYPE_ENTITY_REFERENCE_NODE
        from com.sun.star.xml.dom.NodeType import NOTATION_NODE as NODE_TYPE_NOTATION_NODE
        from com.sun.star.xml.dom.NodeType import PROCESSING_INSTRUCTION_NODE as NODE_TYPE_PROCESSING_INSTRUCTION_NODE
        from com.sun.star.xml.dom.NodeType import TEXT_NODE as NODE_TYPE_TEXT_NODE

        class NodeType(uno.Enum):
            """
            Enum Class

            ENUM NodeType

            See Also:
                `API NodeType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#acac9cbaeea226ed297804c012dc12b16>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.xml.dom.NodeType', value)

            __ooo_ns__: str = 'com.sun.star.xml.dom'
            __ooo_full_ns__: str = 'com.sun.star.xml.dom.NodeType'
            __ooo_type_name__: str = 'enum'

            ATTRIBUTE_NODE = NODE_TYPE_ATTRIBUTE_NODE
            """
            """
            CDATA_SECTION_NODE = NODE_TYPE_CDATA_SECTION_NODE
            """
            """
            COMMENT_NODE = NODE_TYPE_COMMENT_NODE
            """
            """
            DOCUMENT_FRAGMENT_NODE = NODE_TYPE_DOCUMENT_FRAGMENT_NODE
            """
            """
            DOCUMENT_NODE = NODE_TYPE_DOCUMENT_NODE
            """
            """
            DOCUMENT_TYPE_NODE = NODE_TYPE_DOCUMENT_TYPE_NODE
            """
            """
            ELEMENT_NODE = NODE_TYPE_ELEMENT_NODE
            """
            """
            ENTITY_NODE = NODE_TYPE_ENTITY_NODE
            """
            """
            ENTITY_REFERENCE_NODE = NODE_TYPE_ENTITY_REFERENCE_NODE
            """
            """
            NOTATION_NODE = NODE_TYPE_NOTATION_NODE
            """
            """
            PROCESSING_INSTRUCTION_NODE = NODE_TYPE_PROCESSING_INSTRUCTION_NODE
            """
            """
            TEXT_NODE = NODE_TYPE_TEXT_NODE
            """
            """
    else:
        # keep document generators happy
        from ....lo.xml.dom.node_type import NodeType as NodeType


__all__ = ['NodeType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart


class ChartSymbolType(object):
    """
    Const Class

    These values specify the type of the symbol used for data points.
    
    This only applies to diagrams that use symbols like line diagrams.
    
    The default symbols are currently:

    See Also:
        `API ChartSymbolType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart_1_1ChartSymbolType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartSymbolType'
    __ooo_type_name__: str = 'const'

    NONE = -3
    """
    No symbol is used.
    """
    AUTO = -2
    """
    The symbol is selected automatically.
    
    The size of symbol will be dynamic and the type depends on the data row number.
    """
    BITMAPURL = -1
    """
    Take a Bitmap from a URL and use this as symbol.
    
    The bitmap given by the URL set in the property ChartDataPointProperties.SymbolBitmapURL is copied so that the graphic is embedded.
    """
    SYMBOL0 = 0
    """
    The default symbol for row 0 is used.
    """
    SYMBOL1 = 1
    """
    The default symbol for row 1 is used.
    """
    SYMBOL2 = 2
    """
    The default symbol for row 2 is used.
    """
    SYMBOL3 = 3
    """
    The default symbol for row 3 is used.
    """
    SYMBOL4 = 4
    """
    The default symbol for row 4 is used.
    """
    SYMBOL5 = 5
    """
    The default symbol for row 5 is used.
    """
    SYMBOL6 = 6
    """
    The default symbol for row 6 is used.
    """
    SYMBOL7 = 7
    """
    The default symbol for row 7 is used.
    """

__all__ = ['ChartSymbolType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .atom_class_request import AtomClassRequest as AtomClassRequest_e2a60d36
    from .atom_description import AtomDescription as AtomDescription_d6080cdb

class XAtomServer(XInterface_8f010a43):
    """
    an interface to map between strings and ids
    
    a note on atoms:Atoms are abbreviations for strings. When a string gets registered, it is assigned a numeric id so that said string can always be referred to by this id. This way strings have to be transported only once over remote connections. Valid ids are (in this implementation) non zero, signed 32 bit values. An atom of 0 means that the string in question is not registered
    
    Additionally there is the abstraction of atom class:Atoms are grouped into classes, so that an id can be assigned to multiple strings, depending on the class context. The main advantage of this is that atoms in one class may be kept to small numbers, so that bandwidth can be reduced by sending the atoms only as 16 bit values. Note that it is up to the user in this case to handle overflows.

    See Also:
        `API XAtomServer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XAtomServer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XAtomServer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XAtomServer'

    @abstractmethod
    def getAtom(self, atomClass: int, description: str, create: bool) -> int:
        """
        registers or searches for a string
        """
        ...
    @abstractmethod
    def getAtomDescriptions(self, atoms: typing.Tuple[AtomClassRequest_e2a60d36, ...]) -> typing.Tuple[str, ...]:
        """
        returns the strings for an arbitrary amount of atoms of multiple classes
        """
        ...
    @abstractmethod
    def getClass(self, atomClass: int) -> typing.Tuple[AtomDescription_d6080cdb, ...]:
        """
        returns a whole atom class
        """
        ...
    @abstractmethod
    def getClasses(self, atomClasses: uno.ByteSequence) -> typing.Tuple[typing.Tuple[AtomDescription_d6080cdb, ...], ...]:
        """
        returns multiple atom classes
        """
        ...
    @abstractmethod
    def getRecentAtoms(self, atomClass: int, atom: int) -> typing.Tuple[AtomDescription_d6080cdb, ...]:
        """
        returns the atoms that have been registered to a class after an already known atom
        
        Hint to implementor: using ascending atoms is the easiest way to decide, which atoms are recent.
        """
        ...

__all__ = ['XAtomServer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sdbc
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .sql_warning import SQLWarning as SQLWarning_96f10a6a
from ..uno.x_interface import XInterface as XInterface_8f010a43

class DataTruncation(SQLWarning_96f10a6a):
    """
    Exception Class

    reports a DataTruncation warning, on reads, or is thrown as a DataTruncation exception, on writes, when a data value is unexpectedly truncated.
    
    The SQL state for a DataTruncation is 01004.

    See Also:
        `API DataTruncation <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.DataTruncation'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.sdbc.DataTruncation'
    __pyunostruct__: str = 'com.sun.star.sdbc.DataTruncation'

    typeName: str = 'com.sun.star.sdbc.DataTruncation'
    """Literal Constant ``com.sun.star.sdbc.DataTruncation``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, SQLState: typing.Optional[str] = '', ErrorCode: typing.Optional[int] = 0, NextException: typing.Optional[object] = None, Index: typing.Optional[int] = 0, IsParameter: typing.Optional[bool] = False, DuringRead: typing.Optional[bool] = False, DataSize: typing.Optional[int] = 0, TransferSize: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            SQLState (str, optional): SQLState value.
            ErrorCode (int, optional): ErrorCode value.
            NextException (object, optional): NextException value.
            Index (int, optional): Index value.
            IsParameter (bool, optional): IsParameter value.
            DuringRead (bool, optional): DuringRead value.
            DataSize (int, optional): DataSize value.
            TransferSize (int, optional): TransferSize value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "SQLState": SQLState,
            "ErrorCode": ErrorCode,
            "NextException": NextException,
            "Index": Index,
            "IsParameter": IsParameter,
            "DuringRead": DuringRead,
            "DataSize": DataSize,
            "TransferSize": TransferSize,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._index = kwargs["Index"]
        self._is_parameter = kwargs["IsParameter"]
        self._during_read = kwargs["DuringRead"]
        self._data_size = kwargs["DataSize"]
        self._transfer_size = kwargs["TransferSize"]
        inst_keys = ('Index', 'IsParameter', 'DuringRead', 'DataSize', 'TransferSize')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def Index(self) -> int:
        """
        is the index of the parameter or column value.
        """
        return self._index
    
    @Index.setter
    def Index(self, value: int) -> None:
        self._index = value

    @property
    def IsParameter(self) -> bool:
        """
        is TRUE if a parameter value is truncated.
        """
        return self._is_parameter
    
    @IsParameter.setter
    def IsParameter(self, value: bool) -> None:
        self._is_parameter = value

    @property
    def DuringRead(self) -> bool:
        """
        is TRUE if a read was truncated.
        """
        return self._during_read
    
    @DuringRead.setter
    def DuringRead(self, value: bool) -> None:
        self._during_read = value

    @property
    def DataSize(self) -> int:
        """
        contains the number of bytes of data that should have been transferred.
        
        This number may be approximate if data conversions were being performed. The value may be -1 if the size is unknown.
        """
        return self._data_size
    
    @DataSize.setter
    def DataSize(self, value: int) -> None:
        self._data_size = value

    @property
    def TransferSize(self) -> int:
        """
        contains the number of bytes of data actually transferred.
        
        The value may be -1 if the size is unknown.
        """
        return self._transfer_size
    
    @TransferSize.setter
    def TransferSize(self, value: int) -> None:
        self._transfer_size = value


__all__ = ['DataTruncation']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class RasterOperation(metaclass=UnoEnumMeta, type_name="com.sun.star.awt.RasterOperation", name_space="com.sun.star.awt"):
        """Dynamically created class that represents ``com.sun.star.awt.RasterOperation`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.awt.RasterOperation import ALLBITS as RASTER_OPERATION_ALLBITS
        from com.sun.star.awt.RasterOperation import INVERT as RASTER_OPERATION_INVERT
        from com.sun.star.awt.RasterOperation import OVERPAINT as RASTER_OPERATION_OVERPAINT
        from com.sun.star.awt.RasterOperation import XOR as RASTER_OPERATION_XOR
        from com.sun.star.awt.RasterOperation import ZEROBITS as RASTER_OPERATION_ZEROBITS

        class RasterOperation(uno.Enum):
            """
            Enum Class


            See Also:
                `API RasterOperation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt.html#a54da390665a5b42acc81143cd24926fd>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.awt.RasterOperation', value)

            __ooo_ns__: str = 'com.sun.star.awt'
            __ooo_full_ns__: str = 'com.sun.star.awt.RasterOperation'
            __ooo_type_name__: str = 'enum'

            ALLBITS = RASTER_OPERATION_ALLBITS
            """
            All bits which are affected by this operation are set to 1.
            """
            INVERT = RASTER_OPERATION_INVERT
            """
            All bits which are affected by this operation are inverted.
            """
            OVERPAINT = RASTER_OPERATION_OVERPAINT
            """
            sets all pixel as written in the output operation.
            """
            XOR = RASTER_OPERATION_XOR
            """
            uses the pixel written as one and the current pixel as the other operator of an exclusive or-operation.
            """
            ZEROBITS = RASTER_OPERATION_ZEROBITS
            """
            All bits which are affected by this operation are set to 0.
            """
    else:
        # keep document generators happy
        from ...lo.awt.raster_operation import RasterOperation as RasterOperation


__all__ = ['RasterOperation']
